@@ -2,6 +2,7 @@
 import aiohttp as aiohttp
 
 from itle.base import RestApi
+from itle.ddk.ddk_channel_type import DDKChannelType2
 
 
 class DDKPidAuthorityRequest(RestApi):
@@ -26,7 +27,7 @@ class DDKPidAuthorityUrlRequest(RestApi):
     def __init__(self, aio_http: aiohttp, domain: str, port: int):
         super(DDKPidAuthorityUrlRequest, self).__init__(aio_http, domain, port)
         self.ddk_pid_list = None
-        self.channel_type = None
+        self.channel_type: [int] = DDKChannelType2.GENERATE_BIND_URL.value
         self.custom_params = None
         self.amount = None
         self.scratch_card_amount = None
